#    This file is part of unforward
# 
#    Unforward is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#    
#    Unforward is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#


from unforward.emailclients.gmail import GmailClient
from unforward.emailclients.blackberry import BlackberryClient
from unforward.emailclients.outlook import OutlookExpressClient
from unforward.emailclients.yahoo import YahooClient
from unforward.emailclients.lotusnotes import LotusNotesClient
from unforward.emailclients.iphone import iPhoneClient

clients = [
            GmailClient,
            BlackberryClient,
            OutlookExpressClient,
            YahooClient,
            LotusNotesClient,
            iPhoneClient,
        ]



__all__ = ['clients']


